[![version badge]](https://pypi.org/project/hive-messaging/)

[version badge]: https://img.shields.io/pypi/v/hive-messaging?color=limegreen

# hive-messaging

Messaging layer for Hive.

## Installation

### With PIP

```sh
pip install hive-messaging
```

### From source

```sh
git clone https://github.com/gbenson/hive.git
cd hive/libs/messaging
make setup
. .venv/bin/activate
make check
```
